@@ -39,4 +39,14 @@ test_that("test color table",
 			NA))
 			
 			
-		})
\ No newline at end of file
+		})
+
+
+context("fun_schema")
+test_that("test funschema",
+		{
+      skip_on_cran()
+			env_set_test_stacomi()
+			table <- fun_schema()
+			expect_gt(nrow(table),0)
+		})
