@@ -3,16 +3,16 @@ context("report_species")
 
 test_that("test creating an instance of report_species", {
 			skip_on_cran()
-			stacomi(database_expected = TRUE)
+			stacomi(database_expected = TRUE, sch ="test")
 			env_set_test_stacomi()		
 			bilesp <- new("report_species")
 			# split is one of "none", "year", "week", "month
 			
 			bilesp <- choice_c(
 					bilesp,
-					dc = c(5, 6, 12),
+					dc = c(5, 6),
 					split = "year",
-					start_year = "2008",
+					start_year = "2009",
 					end_year = "2012",
 					silent = TRUE
 			)
@@ -29,16 +29,16 @@ test_that("test creating an instance of report_species", {
 
 test_that("test that having ref_taxa in envir_stacomi does not mess with things", {
 			skip_on_cran()
-			stacomi(database_expected = TRUE)
+			stacomi(database_expected = TRUE, sch ="test")
 			env_set_test_stacomi()		
 			bilesp <- new("report_species")
 			# split is one of "none", "year", "week", "month
 			assign("ref_taxa",new("ref_taxa"),envir=envir_stacomi)
 			bilesp <- choice_c(
 					bilesp,
-					dc = c(5, 6, 12),
+					dc = c(5, 6),
 					split = "year",
-					start_year = "2008",
+					start_year = "2009",
 					end_year = "2012",
 					silent = TRUE
 			)	
@@ -51,16 +51,16 @@ test_that("test that having ref_taxa in envir_stacomi does not mess with things"
 
 test_that("test calcule method report_species", {
 			skip_on_cran()
-			stacomi(database_expected = TRUE)
+			stacomi(database_expected = TRUE, sch ="test")
 			env_set_test_stacomi()		
 			bilesp <- new("report_species")
 			# split is one of "none", "year", "week", "month
 			
 			bilesp <- choice_c(
 					bilesp,
-					dc = c(5, 6, 12),
+					dc = c(5, 6),
 					split = "year",
-					start_year = "2008",
+					start_year = "2009",
 					end_year = "2012",
 					silent = TRUE
 			)
@@ -77,17 +77,17 @@ test_that("test calcule method report_species", {
 
 test_that("test method report_species with different options for taxa", {
 			skip_on_cran()
-			stacomi(database_expected = TRUE)
+			stacomi(database_expected = TRUE, sch ="test")
 			env_set_test_stacomi()		
 			bilesp <- new("report_species")
 			# split is one of "none", "year", "week", "month
 			
 			bilesp <- choice_c(
 					bilesp,
-					dc = c(5, 6, 12),
+					dc = c(5, 6),
 					taxa="all",
 					split = "year",
-					start_year = "2008",
+					start_year = "2009",
 					end_year = "2012",
 					silent = TRUE
 			)
@@ -99,10 +99,10 @@ test_that("test method report_species with different options for taxa", {
 					"No data in calcdata after running calculations")
 			bilesp <- choice_c(
 					bilesp,
-					dc = c(5, 6, 12),
-					taxa=c("2038","2086", "2055" ,"2177", "2107", "2108" ,"2109", "2234", "2151", "2183"),
+					dc = c(5, 6),
+					taxa=c("2038","2086", "2055" , "2108" ,  "2183"),
 					split = "year",
-					start_year = "2008",
+					start_year = "2009",
 					end_year = "2012",
 					silent = TRUE
 			)
@@ -118,14 +118,14 @@ test_that("test method report_species with different options for taxa", {
 
 test_that("test that plot method works", {
 			skip_on_cran()
-			stacomi(database_expected = TRUE)	
+			stacomi(database_expected = TRUE, sch ="test")	
 			bilesp <- new("report_species")
 			# split is one of "none", "year", "week", "month			
 			bilesp <- choice_c(
 					bilesp,
-					dc = c(5, 6, 12),
+					dc = c(5, 6),
 					split = "year",
-					start_year = "2008",
+					start_year = "2009",
 					end_year = "2012",
 					silent = TRUE
 			)
@@ -143,9 +143,9 @@ test_that("test that plot method works", {
 					grDevices::colorRampPalette(c("#B56F53", "#270B00"))
 			#length(unique(bilesp@calcdata$taxa_stage)) # 15
 			# here creating a vector of length 15 with nice blending colours
-			color <- c(mycolorrampblue(5),
-					mycolorrampyellow(5),
-					mycolorrampred(5))
+			color <- c(mycolorrampblue(3),
+					mycolorrampyellow(3),
+					mycolorrampred(4))
 			plot(bilesp,
 					plot.type = "barplot",
 					color = color,
@@ -155,15 +155,15 @@ test_that("test that plot method works", {
 
 test_that("test that summary method works", {
 			skip_on_cran()
-			stacomi(database_expected = TRUE)
+			stacomi(database_expected = TRUE, sch ="test")
 			bilesp <- new("report_species")
 			# split is one of "none", "year", "week", "month
 			
 			bilesp <- choice_c(
 					bilesp,
-					dc = c(5, 6, 12),
+					dc = c(5, 6),
 					split = "year",
-					start_year = "2008",
+					start_year = "2009",
 					end_year = "2012",
 					silent = TRUE
 			)
